<?php

namespace Drupal\ji_commerce\EventSubscriber;

use Drupal\state_machine\Event\WorkflowTransitionEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\ji_quickbooks\JIQuickBooksService;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Drupal\user\Entity\User;

/**
 * Class OrderCompleteSubscriber.
 *
 * @package Drupal\ji_commerce
 */
class OrderCompleteSubscriber implements EventSubscriberInterface {

  /**
   * Used for testing. Called on every page load.
   */
  public function checkForRedirection(GetResponseEvent $event) {
    // The void...
  }

  /**
   * Event callback.
   *
   * @param \Drupal\state_machine\Event\WorkflowTransitionEvent $event
   *   The event we subscribed to.
   */
  public function sendQuickBooksData(WorkflowTransitionEvent $event) {
    /** @var \Drupal\commerce_order\Entity\OrderInterface $order */
    $order = $event->getEntity();

    $uid = $order->get('uid')->getString();

    $account = User::load($uid);

    $quickbooks_service = new JIQuickBooksService(FALSE);
    $qbo_customer_id = $quickbooks_service->sendCustomer($quickbooks_service->realmId, $order, $account);
    if ($qbo_customer_id) {
      $qbo_invoice_id = $quickbooks_service->sendInvoice($quickbooks_service->realmId, $order, $qbo_customer_id);
      if ($qbo_invoice_id) {
        $quickbooks_service->sendPayment($quickbooks_service->realmId, $order, $qbo_customer_id, $qbo_invoice_id);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events['commerce_order.place.post_transition'] = ['sendQuickBooksData', -100];
    $events[KernelEvents::REQUEST] = ['checkForRedirection'];
    return $events;
  }

}
