<?php

namespace Drupal\ji_quickbooks\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\State\StateInterface;

/**
 * Processes $_POST data from ji-quickbooks.joshideas.com.
 */
class OAuthResponseController extends ControllerBase {

  /**
   * Dependency injection.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $stateManager;

  /**
   * Constructor.
   *
   * @param \Drupal\Core\State\StateInterface $state_manager
   *   State manager.
   */
  public function __construct(StateInterface $state_manager) {
    $this->stateManager = $state_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('state'));
  }

  /**
   * Work around.
   *
   * Drupal 8 didn't accept $_POST data from the same form that
   * sent a redirect.  This is the only way I got it to work.
   */
  public function saveOauthSettingsPage() {

    if (filter_input(INPUT_POST, 'realm_id')) {
      $this->stateManager->set('ji_quickbooks_settings_realm_id', filter_input(INPUT_POST, 'realm_id'));

      // We just authenticated, mark when this occured so we can
      // auto-renew after five months, starting now.
      $this->stateManager->set('ji_quickbooks_cron_started_on', REQUEST_TIME);
    }

    if (filter_input(INPUT_POST, 'oauth_token')) {
      $this->stateManager->set('ji_quickbooks_settings_access_token', filter_input(INPUT_POST, 'oauth_token'));
    }

    if (filter_input(INPUT_POST, 'oauth_token_secret')) {
      $this->stateManager->set('ji_quickbooks_settings_access_token_secret', filter_input(INPUT_POST, 'oauth_token_secret'));
    }

    if (filter_input(INPUT_POST, 'consumer_key')) {
      $this->stateManager->set('ji_quickbooks_settings_consumer_key', filter_input(INPUT_POST, 'consumer_key'));
    }

    if (filter_input(INPUT_POST, 'consumer_secret')) {
      $this->stateManager->set('ji_quickbooks_settings_consumer_secret', filter_input(INPUT_POST, 'consumer_secret'));
    }

    return new RedirectResponse(Url::fromRoute('ji_quickbooks.form')->toString());
  }

}
